require 'studio_game/game'
require 'studio_game/spec_helper'

module StudioGame
  describe Game do
    before do
      $stdout = StringIO.new
      @game = Game.new("Knuckleheads")

      @initial_health = 100
      @player = Player.new("moe", @initial_health)
      @rounds = 3

      @game.add_player(@player)
    end

    it 'w00ts when high number is rolled' do
      Die.any_instance.stub(:roll).and_return(5)

      @game.play(@rounds)

      @player.health.should == @initial_health + (@rounds * 15)
    end
    
    it 'skips the player when medium number is rolled' do
      Die.any_instance.stub(:roll).and_return(3)

      @game.play(@rounds)

      @player.health.should == @initial_health
    end

    it 'blams the player when a low number is rolled' do
      Die.any_instance.stub(:roll).and_return(2)

      @game.play(@rounds)

      @player.health.should == @initial_health - (@rounds * 10)
    end

    it 'assigns a treasure for points during a player\'s turn' do
      @game.play(1)

      @player.points.should_not be_zero
    end
    
    it "computes total points as the sum of all player points" do
      game = Game.new("Knuckleheads")
    
      player1 = Player.new("moe")
      player2 = Player.new("larry")
    
      game.add_player(player1)
      game.add_player(player2)
    
      player1.found_treasure(Treasure.new(:hammer, 50))
      player1.found_treasure(Treasure.new(:hammer, 50))
      player2.found_treasure(Treasure.new(:crowbar, 400))
    
      game.total_points.should == 500
    end
  end
end
